@@ -49,6 +49,7 @@ def h_newcommand(parser, buf, mac, args, pos):
 #   \begin{theorem}[opt]
 #   - if present, add content of option opt in () parantheses
 #   - add '.'
+#   --> now only used by h_newtheorem()
 #
 def h_theorem(name):
     def handler (parser, buf, mac, args, pos):
@@ -70,6 +71,17 @@ def h_theorem(name):
     # this creates a closure
     return handler
 
+#   \newtheorem
+#
+def h_newtheorem(parser, buf, mac, args, pos):
+    name = parser.get_text_expanded(args[0])
+    title = parser.get_text_expanded(args[2])
+    def f(parms):
+        envs = [defs.Environ(parms, name, args='O', repl=h_theorem(title))]
+        return defs.ModParm(environments=envs)
+    parser.modify_parameters(f)
+    return []
+
 #   heading macros: append '.', unless last char in parms.heading_punct
 #
 def h_heading(parser, buf, mac, args, pos):
@@ -80,6 +92,13 @@ def h_heading(parser, buf, mac, args, pos):
         arg.append(defs.TextToken(arg[-1].pos, '.'))
     return arg
 
+#   \phantom, \hphantom
+#
+def h_phantom(parser, buf, mac, args, pos):
+    if len(parser.get_text_expanded(args[0])) > 0:
+        return [defs.SpecialToken(pos, '\\;')]
+    return []
+
 #   macro \cite[opt]
 #
 def h_cite(parser, buf, mac, args, pos):
@@ -94,9 +113,10 @@ def h_cite(parser, buf, mac, args, pos):
                     defs.ActionToken(pos)]
     return out
 
-#   macro \LTmacros: read macro definitions from file
+#   macro \LTinclude: read macro definitions from file
+#   - this also activates packages
 #
-def h_read_macros(parser, buf, mac, args, pos):
+def h_load_defs(parser, buf, mac, args, pos):
     if not parser.read_macros:
         return []
     file = parser.get_text_expanded(args[0])
@@ -107,3 +127,13 @@ def h_read_macros(parser, buf, mac, args, pos):
     parser.parser_work(latex)
     return []
 
+#   read definitions for a LaTeX package
+#
+def h_load_module(prefix):
+    def f(parser, buf, mac, args, pos):
+        pack = parser.get_text_expanded(args[1])
+        f = utils.get_module_handler(pack, prefix)
+        parser.init_package(pack, f)
+        return []
+    return f
+
