@@ -141,7 +141,9 @@ parser.add_argument('--language', default=default_option_language)
 parser.add_argument('--encoding', default=default_option_encoding)
 parser.add_argument('--replace')
 parser.add_argument('--define')
-parser.add_argument('--python-defs')
+parser.add_argument('--packages', default='*')
+parser.add_argument('--documentclass', default='')
+parser.add_argument('--add-modules', default='')
 parser.add_argument('--extract')
 parser.add_argument('--disable', default=default_option_disable)
 parser.add_argument('--enable', default=default_option_enable)
@@ -212,6 +214,19 @@ if cmdline.server == 'stop':
     tex2txt.fatal('could not kill LT server "' + ltserver_local_cmd + '"')
 
 
+# option --add-modules: read declarations from root document
+# - prepend packages to list from option --packages
+# - possibly overwrite option --documentclass
+#
+if cmdline.add_modules:
+    from yalafi.shell import addpacks
+    dcls, packs = addpacks.addpacks(cmdline)
+    if dcls:
+        cmdline.documentclass = dcls
+    if cmdline.packages:
+        packs += cmdline.packages.split(',')
+    cmdline.packages = ','.join(packs)
+
 # on option --include: add included files to work list
 # otherwise: remove duplicates
 #
@@ -220,7 +235,7 @@ if cmdline.include:
     sys.stderr.flush()
     opts = tex2txt.Options(extr=inclusion_macros, repl=cmdline.replace,
                             defs=cmdline.define, lang=cmdline.language[:2],
-                            pyth=cmdline.python_defs)
+                            dcls=cmdline.documentclass, pack=cmdline.packages)
 
 def skip_file(fn):
     # does file name match regex from option --skip?
